@@ -23,9 +23,9 @@ impl Apps {
      *
      * FROM: <https://docs.github.com/rest/reference/apps#get-the-authenticated-app>
      */
-    pub async fn get_authenticated(&self) -> Result<crate::types::Integration> {
+    pub async fn get_authenticated(&self) -> Result<crate::types::GitHubApp> {
         let url = "/app".to_string();
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -41,22 +41,13 @@ impl Apps {
      *
      * * `code: &str`
      */
-    pub async fn create_from_manifest(
-        &self,
-        code: &str,
-        body: &crate::types::Data,
-    ) -> Result<crate::types::Integration> {
+    pub async fn create_from_manifest(&self, code: &str) -> Result<crate::types::GitHubApp> {
         let url = format!(
             "/app-manifests/{}/conversions",
             crate::progenitor_support::encode_path(&code.to_string()),
         );
 
-        self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
-            .await
+        self.client.post(&url, None).await
     }
 
     /**
@@ -72,7 +63,7 @@ impl Apps {
      */
     pub async fn get_webhook_config_for_app(&self) -> Result<crate::types::WebhookConfig> {
         let url = "/app/hook/config".to_string();
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -99,6 +90,130 @@ impl Apps {
             .await
     }
 
+    /**
+     * List deliveries for an app webhook.
+     *
+     * This function performs a `GET` to the `/app/hook/deliveries` endpoint.
+     *
+     * Returns a list of webhook deliveries for the webhook configured for a GitHub App.
+     *
+     * You must use a [JWT](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/#authenticating-as-a-github-app) to access this endpoint.
+     *
+     * FROM: <https://docs.github.com/rest/reference/apps#list-deliveries-for-an-app-webhook>
+     *
+     * **Parameters:**
+     *
+     * * `per_page: i64` -- Results per page (max 100).
+     * * `cursor: &str` -- Used for pagination: the starting delivery from which the page of deliveries is fetched. Refer to the `link` header for the next and previous page cursors.
+     */
+    pub async fn list_webhook_deliveries(
+        &self,
+        per_page: i64,
+        cursor: &str,
+    ) -> Result<Vec<crate::types::HookDeliveryItem>> {
+        let mut query = String::new();
+        let mut query_args: Vec<String> = Default::default();
+        if !cursor.is_empty() {
+            query_args.push(format!("cursor={}", cursor));
+        }
+        if per_page > 0 {
+            query_args.push(format!("per_page={}", per_page));
+        }
+        for (i, n) in query_args.iter().enumerate() {
+            if i > 0 {
+                query.push('&');
+            }
+            query.push_str(n);
+        }
+        let url = format!("/app/hook/deliveries?{}", query);
+
+        self.client.get(&url, None).await
+    }
+
+    /**
+     * List deliveries for an app webhook.
+     *
+     * This function performs a `GET` to the `/app/hook/deliveries` endpoint.
+     *
+     * As opposed to `list_webhook_deliveries`, this function returns all the pages of the request at once.
+     *
+     * Returns a list of webhook deliveries for the webhook configured for a GitHub App.
+     *
+     * You must use a [JWT](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/#authenticating-as-a-github-app) to access this endpoint.
+     *
+     * FROM: <https://docs.github.com/rest/reference/apps#list-deliveries-for-an-app-webhook>
+     */
+    pub async fn list_all_webhook_deliveries(
+        &self,
+        cursor: &str,
+    ) -> Result<Vec<crate::types::HookDeliveryItem>> {
+        let mut query = String::new();
+        let mut query_args: Vec<String> = Default::default();
+        if !cursor.is_empty() {
+            query_args.push(format!("cursor={}", cursor));
+        }
+        for (i, n) in query_args.iter().enumerate() {
+            if i > 0 {
+                query.push('&');
+            }
+            query.push_str(n);
+        }
+        let url = format!("/app/hook/deliveries?{}", query);
+
+        self.client.get_all_pages(&url, None).await
+    }
+
+    /**
+     * Get a delivery for an app webhook.
+     *
+     * This function performs a `GET` to the `/app/hook/deliveries/{delivery_id}` endpoint.
+     *
+     * Returns a delivery for the webhook configured for a GitHub App.
+     *
+     * You must use a [JWT](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/#authenticating-as-a-github-app) to access this endpoint.
+     *
+     * FROM: <https://docs.github.com/rest/reference/apps#get-a-delivery-for-an-app-webhook>
+     *
+     * **Parameters:**
+     *
+     * * `delivery_id: i64`
+     */
+    pub async fn get_webhook_delivery(
+        &self,
+        delivery_id: i64,
+    ) -> Result<crate::types::HookDelivery> {
+        let url = format!(
+            "/app/hook/deliveries/{}",
+            crate::progenitor_support::encode_path(&delivery_id.to_string()),
+        );
+
+        self.client.get(&url, None).await
+    }
+
+    /**
+     * Redeliver a delivery for an app webhook.
+     *
+     * This function performs a `POST` to the `/app/hook/deliveries/{delivery_id}/attempts` endpoint.
+     *
+     * Redeliver a delivery for the webhook configured for a GitHub App.
+     *
+     * You must use a [JWT](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/#authenticating-as-a-github-app) to access this endpoint.
+     *
+     * FROM: <https://docs.github.com/rest/reference/apps#redeliver-a-delivery-for-an-app-webhook>
+     *
+     * **Parameters:**
+     *
+     * * `delivery_id: i64`
+     */
+    pub async fn redeliver_webhook_delivery(&self, delivery_id: i64) -> Result<crate::types::Data> {
+        let url = format!(
+            "/app/hook/deliveries/{}/attempts",
+            crate::progenitor_support::encode_path(&delivery_id.to_string()),
+        );
+
+        self.client.post(&url, None).await
+    }
+
     /**
      * List installations for the authenticated app.
      *
@@ -146,7 +261,7 @@ impl Apps {
         }
         let url = format!("/app/installations?{}", query);
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -183,7 +298,7 @@ impl Apps {
         }
         let url = format!("/app/installations?{}", query);
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -210,7 +325,7 @@ impl Apps {
             crate::progenitor_support::encode_path(&installation_id.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -536,7 +651,7 @@ impl Apps {
             crate::progenitor_support::encode_path(&access_token.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -614,13 +729,13 @@ impl Apps {
      *
      * * `app_slug: &str`
      */
-    pub async fn get_by_slug(&self, app_slug: &str) -> Result<crate::types::Integration> {
+    pub async fn get_by_slug(&self, app_slug: &str) -> Result<crate::types::GitHubApp> {
         let url = format!(
             "/apps/{}",
             crate::progenitor_support::encode_path(&app_slug.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -660,7 +775,7 @@ impl Apps {
         }
         let url = format!("/installation/repositories?{}", query);
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -705,7 +820,7 @@ impl Apps {
             crate::progenitor_support::encode_path(&account_id.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -745,7 +860,7 @@ impl Apps {
         }
         let url = format!("/marketplace_listing/plans?{}", query);
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -763,7 +878,7 @@ impl Apps {
      */
     pub async fn list_all_plans(&self) -> Result<Vec<crate::types::MarketplaceListingPlan>> {
         let url = "/marketplace_listing/plans".to_string();
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -815,7 +930,7 @@ impl Apps {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -853,7 +968,7 @@ impl Apps {
             query
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -880,7 +995,7 @@ impl Apps {
             crate::progenitor_support::encode_path(&account_id.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -920,7 +1035,7 @@ impl Apps {
         }
         let url = format!("/marketplace_listing/stubbed/plans?{}", query);
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -940,7 +1055,7 @@ impl Apps {
         &self,
     ) -> Result<Vec<crate::types::MarketplaceListingPlan>> {
         let url = "/marketplace_listing/stubbed/plans".to_string();
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -992,7 +1107,7 @@ impl Apps {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -1030,7 +1145,7 @@ impl Apps {
             query
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -1054,7 +1169,7 @@ impl Apps {
             crate::progenitor_support::encode_path(&org.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -1125,7 +1240,7 @@ impl Apps {
             crate::progenitor_support::encode_path(&repo.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -1169,7 +1284,7 @@ impl Apps {
         }
         let url = format!("/user/installations?{}", query);
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -1219,7 +1334,7 @@ impl Apps {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -1317,7 +1432,7 @@ impl Apps {
         }
         let url = format!("/user/marketplace_purchases?{}", query);
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -1335,7 +1450,7 @@ impl Apps {
         &self,
     ) -> Result<Vec<crate::types::UserMarketplacePurchase>> {
         let url = "/user/marketplace_purchases".to_string();
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -1373,7 +1488,7 @@ impl Apps {
         }
         let url = format!("/user/marketplace_purchases/stubbed?{}", query);
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -1391,7 +1506,7 @@ impl Apps {
         &self,
     ) -> Result<Vec<crate::types::UserMarketplacePurchase>> {
         let url = "/user/marketplace_purchases/stubbed".to_string();
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -1418,6 +1533,6 @@ impl Apps {
             crate::progenitor_support::encode_path(&username.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 }
