@@ -53,13 +53,19 @@ impl Interactions {
     pub async fn set_restrictions_for_org(
         &self,
         org: &str,
+        body: &crate::types::InteractionLimit,
     ) -> Result<crate::types::InteractionLimits> {
         let url = format!(
             "/orgs/{}/interaction-limits",
             crate::progenitor_support::encode_path(&org.to_string()),
         );
 
-        self.client.put(&url, None).await
+        self.client
+            .put(
+                &url,
+                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
+            )
+            .await
     }
 
     /**
@@ -130,6 +136,7 @@ impl Interactions {
         &self,
         owner: &str,
         repo: &str,
+        body: &crate::types::InteractionLimit,
     ) -> Result<crate::types::InteractionLimits> {
         let url = format!(
             "/repos/{}/{}/interaction-limits",
@@ -137,7 +144,12 @@ impl Interactions {
             crate::progenitor_support::encode_path(&repo.to_string()),
         );
 
-        self.client.put(&url, None).await
+        self.client
+            .put(
+                &url,
+                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
+            )
+            .await
     }
 
     /**
@@ -191,9 +203,15 @@ impl Interactions {
      */
     pub async fn set_restrictions_for_authenticated_user(
         &self,
+        body: &crate::types::InteractionLimit,
     ) -> Result<crate::types::InteractionLimits> {
         let url = "/user/interaction-limits".to_string();
-        self.client.put(&url, None).await
+        self.client
+            .put(
+                &url,
+                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
+            )
+            .await
     }
 
     /**
