@@ -43,7 +43,7 @@ impl Packages {
             crate::progenitor_support::encode_path(&package_name.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -53,7 +53,7 @@ impl Packages {
      *
      * Deletes an entire package in an organization. You cannot delete a public package if any version of the package has more than 5,000 downloads. In this scenario, contact GitHub support for further assistance.
      *
-     * To use this endpoint, you must have admin permissions in the organization and authenticate using an access token with the `packages:read` scope. In addition:
+     * To use this endpoint, you must have admin permissions in the organization and authenticate using an access token with the `packages:read` and `packages:delete` scopes. In addition:
      * - If `package_type` is not `container`, your token must also include the `repo` scope.
      * - If `package_type` is `container`, you must also have admin permissions to the container you want to delete.
      *
@@ -92,7 +92,7 @@ impl Packages {
      *   - The package was deleted within the last 30 days.
      *   - The same package namespace and version is still available and not reused for a new package. If the same package namespace is not available, you will not be able to restore your package. In this scenario, to restore the deleted package, you must delete the new package that uses the deleted package's namespace first.
      *
-     * To use this endpoint, you must have admin permissions in the organization and authenticate using an access token with the `packages:read` and `packages:write` scope. In addition:
+     * To use this endpoint, you must have admin permissions in the organization and authenticate using an access token with the `packages:read` and `packages:write` scopes. In addition:
      * - If `package_type` is not `container`, your token must also include the `repo` scope.
      * - If `package_type` is `container`, you must also have admin permissions to the container that you want to restore.
      *
@@ -187,7 +187,7 @@ impl Packages {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -228,7 +228,7 @@ impl Packages {
             query
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -265,7 +265,7 @@ impl Packages {
             crate::progenitor_support::encode_path(&package_version_id.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -275,7 +275,7 @@ impl Packages {
      *
      * Deletes a specific package version in an organization. If the package is public and the package version has more than 5,000 downloads, you cannot delete the package version. In this scenario, contact GitHub support for further assistance.
      *
-     * To use this endpoint, you must have admin permissions in the organization and authenticate using an access token with the `packages:read` scope. In addition:
+     * To use this endpoint, you must have admin permissions in the organization and authenticate using an access token with the `packages:read` and `packages:delete` scopes. In addition:
      * - If `package_type` is not `container`, your token must also include the `repo` scope.
      * - If `package_type` is `container`, you must also have admin permissions to the container you want to delete.
      *
@@ -317,7 +317,7 @@ impl Packages {
      *   - The package was deleted within the last 30 days.
      *   - The same package namespace and version is still available and not reused for a new package. If the same package namespace is not available, you will not be able to restore your package. In this scenario, to restore the deleted package, you must delete the new package that uses the deleted package's namespace first.
      *
-     * To use this endpoint, you must have admin permissions in the organization and authenticate using an access token with the `packages:read` and `packages:write` scope. In addition:
+     * To use this endpoint, you must have admin permissions in the organization and authenticate using an access token with the `packages:read` and `packages:write` scopes. In addition:
      * - If `package_type` is not `container`, your token must also include the `repo` scope.
      * - If `package_type` is `container`, you must also have admin permissions to the container that you want to restore.
      *
@@ -376,7 +376,7 @@ impl Packages {
             crate::progenitor_support::encode_path(&package_name.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -386,7 +386,7 @@ impl Packages {
      *
      * Deletes a package owned by the authenticated user. You cannot delete a public package if any version of the package has more than 5,000 downloads. In this scenario, contact GitHub support for further assistance.
      *
-     * To use this endpoint, you must authenticate using an access token with the `packages:read` and `packages:delete` scope.
+     * To use this endpoint, you must authenticate using an access token with the `packages:read` and `packages:delete` scopes.
      * If `package_type` is not `container`, your token must also include the `repo` scope.
      *
      * FROM: <https://docs.github.com/rest/reference/packages#delete-a-package-for-the-authenticated-user>
@@ -421,7 +421,7 @@ impl Packages {
      *   - The package was deleted within the last 30 days.
      *   - The same package namespace and version is still available and not reused for a new package. If the same package namespace is not available, you will not be able to restore your package. In this scenario, to restore the deleted package, you must delete the new package that uses the deleted package's namespace first.
      *
-     * To use this endpoint, you must authenticate using an access token with the `packages:read` and `packages:write` scope. If `package_type` is not `container`, your token must also include the `repo` scope.
+     * To use this endpoint, you must authenticate using an access token with the `packages:read` and `packages:write` scopes. If `package_type` is not `container`, your token must also include the `repo` scope.
      *
      * FROM: <https://docs.github.com/rest/reference/packages#restore-a-package-for-the-authenticated-user>
      *
@@ -508,7 +508,7 @@ impl Packages {
             query
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -547,7 +547,7 @@ impl Packages {
             query
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -581,7 +581,7 @@ impl Packages {
             crate::progenitor_support::encode_path(&package_version_id.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -591,7 +591,7 @@ impl Packages {
      *
      * Deletes a specific package version for a package owned by the authenticated user.  If the package is public and the package version has more than 5,000 downloads, you cannot delete the package version. In this scenario, contact GitHub support for further assistance.
      *
-     * To use this endpoint, you must have admin permissions in the organization and authenticate using an access token with the `packages:read` scope.
+     * To use this endpoint, you must have admin permissions in the organization and authenticate using an access token with the `packages:read` and `packages:delete` scopes.
      * If `package_type` is not `container`, your token must also include the `repo` scope.
      *
      * FROM: <https://docs.github.com/rest/reference/packages#delete-a-package-version-for-the-authenticated-user>
@@ -629,7 +629,7 @@ impl Packages {
      *   - The package was deleted within the last 30 days.
      *   - The same package namespace and version is still available and not reused for a new package. If the same package namespace is not available, you will not be able to restore your package. In this scenario, to restore the deleted package, you must delete the new package that uses the deleted package's namespace first.
      *
-     * To use this endpoint, you must authenticate using an access token with the `packages:read` and `packages:write` scope. If `package_type` is not `container`, your token must also include the `repo` scope.
+     * To use this endpoint, you must authenticate using an access token with the `packages:read` and `packages:write` scopes. If `package_type` is not `container`, your token must also include the `repo` scope.
      *
      * FROM: <https://docs.github.com/rest/reference/packages#restore-a-package-version-for-the-authenticated-user>
      *
@@ -686,7 +686,7 @@ impl Packages {
             crate::progenitor_support::encode_path(&package_name.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -720,7 +720,7 @@ impl Packages {
             crate::progenitor_support::encode_path(&package_name.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 
     /**
@@ -750,7 +750,7 @@ impl Packages {
             crate::progenitor_support::encode_path(&package_name.to_string()),
         );
 
-        self.client.get_all_pages(&url).await
+        self.client.get_all_pages(&url, None).await
     }
 
     /**
@@ -787,6 +787,6 @@ impl Packages {
             crate::progenitor_support::encode_path(&package_version_id.to_string()),
         );
 
-        self.client.get(&url).await
+        self.client.get(&url, None).await
     }
 }
